Returns the minimum pairwise distance among selected points \(T_k\). A set of points that is more dispersed will exhibit a higher value.
Arguments
- d
Pairwise distance matrix or
distobject. Ignored whenpointsis supplied.- idx
Integer vector of selected row/col indices.
- points
Optional
N x dimnumeric coordinate matrix. When supplied, the score is computed fromstats::dist()on the selected sub-coordinates only (k x k).
Value
MinDist() returns a numeric specifying the minimum distance between
two selected points (or NA_real_, if length(idx) < 2).
Details
The solvers in this package (FarFirst(), DropAdd(), Grasp())
already attach the achieved \(T_k\) as a score attribute.
MinDist() allows arbitrary selections to be scored, or an existing
selection to be scored against a different distance matrix.
See also
FarFirst(), DropAdd(), Grasp() and ExactMaxMin().